Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(616)

Unified Diff: chrome/browser/ui/libgtkui/gtk_ui.h

Issue 2610883004: Gtk3: Rename Gtk2UI and Get[FB]GColor (Closed)
Patch Set: Rebase Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/libgtkui/gconf_listener.cc ('k') | chrome/browser/ui/libgtkui/gtk_ui.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/libgtkui/gtk_ui.h
diff --git a/chrome/browser/ui/libgtkui/gtk_ui.h b/chrome/browser/ui/libgtkui/gtk_ui.h
index 24e744ecde4b5432bd7d7b770d411c1f5c37b7bb..ba3dded32500b4d83d7cd17c1b70184be1fc04f9 100644
--- a/chrome/browser/ui/libgtkui/gtk_ui.h
+++ b/chrome/browser/ui/libgtkui/gtk_ui.h
@@ -27,10 +27,10 @@ class GConfListener;
// Interface to GTK2 desktop features.
//
-class Gtk2UI : public views::LinuxUI {
+class GtkUi : public views::LinuxUI {
public:
- Gtk2UI();
- ~Gtk2UI() override;
+ GtkUi();
+ ~GtkUi() override;
typedef base::Callback<ui::NativeTheme*(aura::Window* window)>
NativeThemeGetter;
@@ -204,13 +204,13 @@ class Gtk2UI : public views::LinuxUI {
NonClientMiddleClickAction middle_click_action_;
// Used to override the native theme for a window. If no override is provided
// or the callback returns NULL, Gtk2UI will default to a NativeThemeGtk2
// instance.
NativeThemeGetter native_theme_overrider_;
float device_scale_factor_ = 1.0f;
- DISALLOW_COPY_AND_ASSIGN(Gtk2UI);
+ DISALLOW_COPY_AND_ASSIGN(GtkUi);
};
} // namespace libgtkui
@@ -220,6 +220,6 @@ class Gtk2UI : public views::LinuxUI {
// interface, because eventually this .so will be loaded through dlopen at
// runtime so our main binary can conditionally load GTK2 or GTK3 or EFL or
// QT or whatever.
-LIBGTKUI_EXPORT views::LinuxUI* BuildGtk2UI();
+LIBGTKUI_EXPORT views::LinuxUI* BuildGtkUi();
#endif // CHROME_BROWSER_UI_LIBGTKUI_GTK_UI_H_
« no previous file with comments | « chrome/browser/ui/libgtkui/gconf_listener.cc ('k') | chrome/browser/ui/libgtkui/gtk_ui.cc » ('j') | no next file with comments »
@@ -204,13 +204,13 @@ class Gtk2UI : public views::LinuxUI {
NonClientMiddleClickAction middle_click_action_;
// Used to override the native theme for a window. If no override is provided
- // or the callback returns NULL, Gtk2UI will default to a NativeThemeGtk2
+ // or the callback returns NULL, GtkUi will default to a NativeThemeGtk2
// instance.
NativeThemeGetter native_theme_overrider_;

Powered by Google App Engine
This is Rietveld 408576698